@@ -4,10 +4,10 @@ Classes connecting `Port` of foreign `System` to transfer variable values.
 import copy
 import logging
 import weakref
-from typing import Callable, Dict, List, Optional, Tuple, Union
+from typing import Callable, Dict, Iterable, List, Optional, Tuple, Union
 
 from cosapp.ports import units
-from cosapp.ports.port import ExtensiblePort, PortType
+from cosapp.ports.port import BasePort, PortType
 from cosapp.utils.helpers import check_arg, is_numerical
 
 logger = logging.getLogger(__name__)
@@ -42,22 +42,22 @@ class Connector:
     ----------
     name : str
         Name of the connector
-    source : ExtensiblePort
+    source : BasePort
         Port from which originate the variables
     mapping : str or List[str] or Dict[str, str]
         (List of) common name(s) or mapping name dictionary
-    sink : ExtensiblePort
+    sink : BasePort
         Port to which the variables are transferred
     """
 
     def __init__(
         self,
         name: str,
-        sink: ExtensiblePort,
-        source: ExtensiblePort,
+        sink: BasePort,
+        source: BasePort,
         mapping: Union[str, List[str], Dict[str, str], None] = None,
     ):
-        """Connector constructor from the two `ExtensiblePort` to link and the list of variables to map.
+        """Connector constructor from the two `BasePort` to link and the list of variables to map.
 
         If no mapping is provided, connection will be made between variables based on their names. 
         If a name mapping is provided as a list, the name should be present in both port. And if 
@@ -68,9 +68,9 @@ class Connector:
         ----------
         name : str
             Name of the connector
-        sink : ExtensiblePort
+        sink : BasePort
             Port to which the variables are transferred.
-        source : ExtensiblePort
+        source : BasePort
             Port from which originate the variables.
         mapping : str or List[str] or Dict[str, str], optional
             (List of) common name(s) or mapping name dictionary; default None (i.e. no mapping).
@@ -80,43 +80,27 @@ class Connector:
         ConnectorError
             If the connection between the `source` and the `sink` is not possible to establish.
         """
+        self.__check_port(sink, 'sink')
+        self.__check_port(source, 'source')
         self._name = name  # type: str
 
-        if not source.owner:
-            raise ConnectorError("Source owner is undefined.")
-
-        if not sink.owner:
-            raise ConnectorError("Sink owner is undefined.")
-
         if source is sink:
             raise ConnectorError("Source and sink cannot be the same object.")
 
-        self._source = weakref.ref(source)  # type: ExtensiblePort
-        self._sink = weakref.ref(sink)  # type: ExtensiblePort
-
         # Generate mapping dictionary
         if mapping is None:
-            mapping = dict([(v, v) for v in sink if v in source])
+            mapping = dict((v, v) for v in sink if v in source)
         elif isinstance(mapping, str):
-            mapping = dict([(mapping, mapping)])
+            mapping = {mapping: mapping}
         elif not isinstance(mapping, dict):
             mapping = dict(zip(mapping, mapping))
 
         self._mapping = mapping  # type: Dict[str, str]
-
-        # Validate the connection based on variable attributes
-        for target, origin in self._mapping.items():
-            if origin not in self.source:
-                raise ConnectorError(
-                    f"Source port {self.source} has no variable '{origin}'"
-                )
-            if target not in self.sink:
-                raise ConnectorError(
-                    f"Sink port {self.source} has no variable '{target}'"
-                )
+        self._source = self.__get_port(source, sink=False, check=False)  # type: weakref.ReferenceType[BasePort]
+        self._sink = self.__get_port(sink, sink=True, check=False)  # type: weakref.ReferenceType[BasePort]
 
         self._unit_conversions = dict(
-            [(name, None) for name in self._mapping]
+            (name, None) for name in self._mapping
         )  # type: Dict[str, Optional[Tuple[float, float]]]
 
         self.update_unit_conversion()
@@ -134,54 +118,63 @@ class Connector:
         return self._name
 
     @property
-    def source(self) -> ExtensiblePort:
-        """`ExtensiblePort`: Port from which transferred values originate."""
+    def source(self) -> BasePort:
+        """`BasePort`: Port from which transferred values originate."""
         return self._source()
 
     @source.setter
-    def source(self, port: ExtensiblePort) -> None:
-        check_arg(port, 'source', ExtensiblePort)
-
-        if len(self.source) != len(port):
-            raise TypeError(
-                f"New port {port} has not the same variables as the source {self.source}."
-            )
-
-        for variable in self.source:
-            if variable not in port:
-                raise AttributeError(
-                    f"Source variable {variable} does not exist in port {port}."
-                )
-
-        self._source = weakref.ref(port)
+    def source(self, port: BasePort) -> None:
+        self._source = self.__get_port(port, sink=False, check=True)
+        self.update_unit_conversion()
 
     @property
-    def sink(self) -> ExtensiblePort:
-        """`ExtensiblePort`: Port to which values are transferred."""
+    def sink(self) -> BasePort:
+        """`BasePort`: Port to which values are transferred."""
         return self._sink()
 
     @sink.setter
-    def sink(self, port: ExtensiblePort) -> None:
-        check_arg(port, 'sink', ExtensiblePort)
+    def sink(self, port: BasePort) -> None:
+        self._sink = self.__get_port(port, sink=True, check=True)
+        self.update_unit_conversion()
 
-        if len(self.sink) != len(port):
-            raise TypeError(
-                f"New port {port} has not the same variables as the sink {self.sink}."
-            )
+    def __get_port(self, port: BasePort, sink: bool, check=True) -> "weakref.ref[BasePort]":
+        """Returns a weakref to `port`, after compatibility check with internal mapping."""
+        if sink:
+            name = 'sink'
+            variables = self.sink_variables()
+        else:
+            name = 'source'
+            variables = self.source_variables()
 
-        for variable in self.sink:
+        if check:
+            self.__check_port(port, name)
+
+        for variable in variables:
             if variable not in port:
-                raise AttributeError(
-                    f"Sink variable {variable} does not exist in port {port}."
+                raise ConnectorError(
+                    f"{name.title()} variable {variable!r} does not exist in port {port}."
                 )
+        
+        return weakref.ref(port)
 
-        self._sink = weakref.ref(port)
+    @staticmethod
+    def __check_port(port: BasePort, name: str) -> None:
+        check_arg(port, name, BasePort, stack_shift=1)
+
+        if not port.owner:
+            raise ConnectorError(f"{name.title()} owner is undefined.")
 
     @property
     def variable_mapping(self) -> Dict[str, str]:
         """Dict[str, str] : Variable name mapping between the sink (key) and the source (value)."""
         return self._mapping
 
+    def sink_variables(self) -> Iterable:
+        return self._mapping.keys()
+
+    def source_variables(self) -> Iterable:
+        return self._mapping.values()
+
     def set_perturbation(self, name: str, value: float) -> None:
         """Add a perturbation on a connector.
         
@@ -193,7 +186,7 @@ class Connector:
             Perturbation value
         """
         if self._unit_conversions[name] is None:
-            ValueError(f"'{name}' does not have a numerical type.")
+            ValueError(f"{name!r} does not have a numerical type.")
 
         s, a = self._unit_conversions[name]
         self._unit_conversions[name] = s, a + value
@@ -229,6 +222,8 @@ class Connector:
         UnitError
             If unit conversion from source to sink is not possible
         """
+        source, sink = self.source, self.sink
+        mapping = self.variable_mapping
 
         def update_one_connection(key: str) -> None:
             """Update the unit converter of the connected key.
@@ -238,23 +233,26 @@ class Connector:
             key : str
                 Name of the connected variable for which the unit converter should be updated.
             """
-            source_name = self.variable_mapping[key]
-            source_unit = self.source.get_details(source_name).unit
-            target_unit = self.sink.get_details(key).unit
+            source_name = mapping[key]
+            origin = source.get_details(source_name)
+            target = sink.get_details(key)
             # Get the conversion between unit and check it is valid
-            converter = units.get_conversion(source_unit, target_unit)
+            converter = units.get_conversion(origin.unit, target.unit)
             if converter is None:
                 # Print a warning if one hand of the connexion is a valid unit but not the other one
-                if units.is_valid_units(source_unit):
+                message = lambda origin_status, target_status: (
+                    f"Connector source {origin.full_name!r} {origin_status}, but target {target.full_name!r} {target_status}."
+                )
+                if units.is_valid_units(origin.unit):
                     logger.warning(
-                        f"Connector source has physical unit {source_unit}, but the sink is dimensionless."
+                        message(f"has physical unit {origin.unit}", "is dimensionless")
                     )
-                elif units.is_valid_units(target_unit):
+                elif units.is_valid_units(target.unit):
                     logger.warning(
-                        f"Connector source is dimensionless, but the sink has physical unit {target_unit}."
+                        message("is dimensionless", f"has physical unit {target.unit}")
                     )
 
-                if is_numerical(self.sink[key]):
+                if is_numerical(sink[key]):
                     converter = (1.0, 0.0)
 
             self._unit_conversions[key] = converter
@@ -291,36 +289,25 @@ class Connector:
                 except TypeError:
                     setattr(sink, key, copy.deepcopy(target))
 
-    def to_dict(self) -> Dict[str, Union[str, Tuple[Dict[str, str], str]]]:
-        """Convert this connector to a dictionary.
+    def to_dict(self) -> Dict[str, Union[Tuple[str, str], Tuple[str, str, Dict[str, str]]]]:
+        """Convert connector to a single-key dictionary.
 
-        The dictionary returned has the following structure
-        Dict[str, Tuple[Dict[str, str], str]]::
+        The key is the connector name; the associated value
+        depends on the variable name mapping.
 
-           {
-             port_name: (variable mapping, source name)
-           }
+        If the mapping is complete, with identical names,
+        the name mapping is omitted, and the output
+        dictionary is formatted as:
+            {name: (target_name, source_name)}
 
-        Or if the mapping is complete with the same name::
-
-           {
-             port_name: source name
-           }
+        Otherwise, it is formatted as:
+            {name: (target_name, source_name, name_mapping)}
 
         Returns
         -------
         dict
             Dictionary representing this connector
         """
-        tmp = dict()
-
-        target = self.sink.contextual_name
-        if self.sink.owner is self.source.owner.parent:
-            target = self.sink.name
-        origin = self.source.contextual_name
-        if self.source.owner is self.sink.owner.parent:
-            origin = self.source.name
-
         # If the mapping is full and with the same nomenclature
         same_nomenclature = False
         if len(self._mapping) == len(self.source) == len(self.sink):
@@ -330,9 +317,32 @@ class Connector:
                     same_nomenclature = False
                     break
 
+        target, origin = self.port_names()
         if same_nomenclature:
-            tmp[self.name] = (target, origin)
+            info = (target, origin)
         else:
-            tmp[self.name] = (target, origin, self._mapping.copy())
+            info = (target, origin, self._mapping.copy())
 
-        return tmp
+        return {self.name: info}
+
+    def port_names(self) -> Tuple[str, str]:
+        """Returns source and sink contextual names as a str tuple.
+
+        Returns
+        -------
+        tuple
+            (source_name, sink_name) tuple
+        """
+        source, sink = self.source, self.sink
+
+        if source.owner is sink.owner.parent:
+            origin = source.name
+        else:
+            origin = source.contextual_name
+
+        if sink.owner is source.owner.parent:
+            target = sink.name
+        else:
+            target = sink.contextual_name
+        
+        return target, origin
