@@ -1,6 +1,6 @@
 import logging
 from io import StringIO
-from typing import (Any, Callable, Dict, List, NoReturn, Optional, Sequence,
+from typing import (Any, Callable, Dict, List, Optional, Sequence,
                     Tuple, Union)
 
 import numpy
@@ -41,7 +41,7 @@ class NonLinearSolver(AbstractSolver):
         owner: "Optional[cosapp.systems.System]" = None, 
         method: Union[NonLinearMethods, str] = NonLinearMethods.NR, 
         **kwargs
-    ) -> NoReturn:
+    ) -> None:
         """Initialize a driver
 
         Parameters
@@ -141,22 +141,23 @@ class NonLinearSolver(AbstractSolver):
 
         return results
 
-    def _print_solution(self) -> NoReturn:  # TODO better returning a string
+    def _print_solution(self) -> None:  # TODO better returning a string
         """Print the solution in the log."""
         if self.options['verbose']:
             # TODO move it in MathematicalProblem
-            logger.info('Parameters [{}]: '.format(len(self.solution)))
+            logger.info(f"Parameters [{len(self.solution)}]: ")
             for k, v in self.solution.items():
-                logger.info('   # ' + str(k) + ': ' + str(v))
+                logger.info(f"   # {k}: {v}")
 
             for name, residue in self.problem.residues.items():
                 value = numpy.asarray(residue.value)
                 if value.ndim > 0:
-                    msg = 'Residues [{}]: \n   # ({}'.format(len(self.problem.residues), name)
-                    msg += '\n   #  {}'.format(" " * len(name)).join([", {:.5g}".format(v) for v in value])
-                    msg += ')\n'
+                    spacing = " " * len(name)
+                    msg = f"Residues [{len(self.problem.residues)}]: \n   # ({name}"
+                    msg += f"\n   #  {spacing}".join([f", {v:.5g}" for v in value])
+                    msg += ")\n"
                 else:
-                    logger.info('   # ({}, {:.5g})'.format(name, value))
+                    logger.info(f"   # ({name}, {value:.5g})")
 
             tol = numpy.max(numpy.abs(self.problem.residues_vector))
             try:
@@ -164,9 +165,9 @@ class NonLinearSolver(AbstractSolver):
                 target = self.options[option]
             except:
                 target = 0
-            logger.debug(' # Current tolerance {} for target {}'.format(tol, target))
+            logger.debug(f" # Current tolerance {tol} for target {target}")
 
-    def _precompute(self) -> NoReturn:
+    def _precompute(self) -> None:
         """List all iteratives variables and get the initial values."""
         super()._precompute()
 
@@ -175,10 +176,11 @@ class NonLinearSolver(AbstractSolver):
                 self.problem.extend(child.get_problem(), copy=False)
                 self.initial_values = numpy.append(self.initial_values, child.get_init(self.force_init))
             else:
-                logger.warning('Including Driver "{}" without iteratives in Driver "{}" is not numerically advised.'
-                                ''.format(child.name, self.name))
+                logger.warning(
+                    f"Including Driver {child.name!r} without iteratives in Driver {self.name!r} is not numerically advised."
+                )
 
-    def compute(self) -> NoReturn:
+    def compute(self) -> None:
         """Run the resolution method to find free vars values that annul residues
         """
 
@@ -208,7 +210,7 @@ class NonLinearSolver(AbstractSolver):
             if results.success:
                 self.status = ''
                 self.error_code = '0'
-                logger.info('solver : {}{}'.format(self.name, results.message))
+                logger.info(f"solver : {self.name}{results.message}")
             else:
                 self.status = 'ERROR'
                 self.error_code = '9'
@@ -302,10 +304,10 @@ class NonLinearSolver(AbstractSolver):
                     container = StringIO()
                     numpy.savetxt(container, info["jac"], delimiter=",")
                     jacobian = container.getvalue()
-                    unknowns = ",".join(self.problem.unknowns_names)
+                    unknowns = ", ".join(self.problem.unknowns_names)
                     message += f"New Jacobian matrix:\n,{unknowns}\n"
                     for residue, line in zip(self.problem.residues_names, jacobian.splitlines()):
-                        message += f"{residue},{line}\n"
+                        message += f"{residue}, {line}\n"
 
             if len(self.__trace) > 0:
                 if len(self.__trace) == 1:
@@ -348,8 +350,10 @@ class NonLinearSolver(AbstractSolver):
                 desc='A parameter determining the initial step bound factor * norm(diag * x). Should be in the interval [0.1, 1].')
             self.options.declare('partial_jac', True, dtype=bool, allow_none=False,
                 desc='Defines if partial Jacobian updates can be computed before a complete Jacobian matrix update.')
-            self.options.declare('partial_jac_tries', 5, dtype=int, allow_none=False, lower=1, upper=5,
+            self.options.declare('partial_jac_tries', 10, dtype=int, allow_none=False, lower=1, upper=10,
                 desc='Defines how many partial Jacobian updates can be tried before a complete Jacobian matrix update.')
+            self.options.declare('jac_update_tol', 0.01, dtype=float, allow_none=False, lower=0, upper=1,
+                desc='Tolerance level for partial Jacobian matrix update, based on nonlinearity estimation.')
             self.options.declare('recorder', None, allow_none=True,
                 desc='A recorder to store solver intermediate results.')
             self.options.declare('lower_bound', None, dtype=numpy.ndarray, allow_none=True,
