@@ -30,7 +30,7 @@ class Variable:
     ----------
     name : str
         Variable name.
-    port : ExtensiblePort
+    port : BasePort
         Port to which belong the variable
     value : Any
         Variable value
@@ -62,7 +62,7 @@ class Variable:
     #     a way to change the value no passing through the Port (which is bad for the
     #     clean dirty logic).
     #   Disadvantage : the logic to store the details and the value is a bit messy in
-    #     ExtensiblePort.add_variable
+    #     BasePort.add_variable
 
     __slots__ = [
         "__weakref__",
@@ -236,7 +236,7 @@ class Variable:
     def __init__(
         self,
         name: str,
-        port: "cosapp.ports.port.ExtensiblePort",
+        port: "cosapp.ports.port.BasePort",
         value: Any,
         unit: str = "",
         dtype: Types = None,
@@ -250,8 +250,8 @@ class Variable:
     ):
         self._name = self.name_check(name)
 
-        from cosapp.ports.port import ExtensiblePort
-        check_arg(port, 'port', ExtensiblePort)
+        from cosapp.ports.port import BasePort
+        check_arg(port, 'port', BasePort)
         self._port = port
 
         check_arg(unit, 'unit', str)
@@ -344,7 +344,17 @@ class Variable:
         return self.name
 
     def __repr__(self) -> str:
-        msg = {"name": self.name, "unit": f" {self.unit}" if self.unit else ""}
+        return self._repr_markdown_()
+        
+    def _repr_markdown_(self) -> str:
+        """Returns the representation of this variable in Markdown format.
+
+        Returns
+        -------
+        str
+            Markdown formatted representation
+        """
+        msg = {"name":f"**{self.name}**" , "unit": f" {self.unit}" if self.unit else ""}
         value = self.value
         try:
             msg["value"] = f"{value:.5g}"
@@ -355,30 +365,36 @@ class Variable:
             self.valid_range if self.valid_range is not None else (None, None)
         )
         min_limit, max_limit = self.limits if self.limits is not None else (None, None)
+        
+        left_bracket = "&#10647;"
+        left_arrow = "&#10205;"
+        right_arrow = "&#10206;"
+        right_bracket = "&#10648;"
+        lock_icon = "&#128274;"
         if min_limit is None or numpy.all(numpy.isinf(min_limit)):
             msg["min_limit"] = ""
         else:
-            msg["min_limit"] = f" &#10647; {min_limit:.5g} &#10205; "
+            msg["min_limit"] = f" {left_bracket} {min_limit:.5g} {left_arrow} "
         if max_limit is None or numpy.all(numpy.isinf(max_limit)):
             msg["max_limit"] = ""
         else:
-            msg["max_limit"] = f" &#10206; {max_limit:.5g} &#10648; "
+            msg["max_limit"] = f" {right_arrow} {max_limit:.5g} {right_bracket} "
         if min_valid is None or min_limit == min_valid or numpy.all(numpy.isinf(min_valid)):
             msg["min_valid"] = ""
         else:
-            msg["min_valid"] = f"{min_valid:.5g} &#10205; "
+            msg["min_valid"] = f"{min_valid:.5g} {left_arrow} "
         if max_valid is None or max_limit == max_valid or numpy.all(numpy.isinf(max_valid)):
             msg["max_valid"] = ""
         else:
-            msg["max_valid"] = f" &#10206; {max_valid:.5g}"
+            msg["max_valid"] = f" {right_arrow} {max_valid:.5g}"
         if self.description:
-            msg["description"] = f" # {self.description}"
+            msg["description"] = f" | {self.description}"
         else:
-            msg["description"] = ""
+            msg["description"] = " |"
 
         scope_format = {
-            Scope.PRIVATE: " &#128274;&#128274; ",
-            Scope.PROTECTED: " &#128274; ",
+            Scope.PRIVATE: f" {lock_icon*2} ",
+            Scope.PROTECTED: f" {lock_icon} ",
             Scope.PUBLIC: "",
         }
         msg["scope"] = scope_format[self.scope]
@@ -394,8 +410,9 @@ class Variable:
             "{name}{scope}: {value!s}{unit}"
             "{separator}{min_limit}{min_valid}{range}{max_valid}{max_limit}"
             "{description}".format(**msg)
-        )
-
+        )  
+        
+        
     def __json__(self) -> Dict[str, Any]:
         """JSONable dictionary representing a variable.
         
