@@ -17,7 +17,7 @@ def test_ComplexDuct():
     s.add_driver(RunOnce("first run"))
     s.add_driver(NonLinearSolver("design"))
     s.run_drivers()
-    assert s.bleed.fl2_out.W / 1.01010101010101 == pytest.approx(1., rel=1e-5)
-    assert s.merger.fl2_in.W / 1.01010101010101 == pytest.approx(1., rel=1e-5)
-    assert s.bleed.fl2_out.Pt / 1000. == pytest.approx(1., rel=1e-5)
-    assert s.merger.fl2_in.Pt / 1000. == pytest.approx(1., rel=1e-5)
+    assert s.bleed.fl2_out.W == pytest.approx(100 / 99, rel=1e-5)
+    assert s.merger.fl2_in.W == pytest.approx(100 / 99, rel=1e-5)
+    assert s.bleed.fl2_out.Pt == pytest.approx(1000, rel=1e-5)
+    assert s.merger.fl2_in.Pt == pytest.approx(1000, rel=1e-5)
